{
	"name" : "Products date of expiry",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Enterprise Specific Modules/Food Industries",
	"depends" : ["base", "account", "product", "stock"],
	"init_xml" : [],
	"demo_xml" : ["product_expiry_demo.xml"],
	"description": "Track different dates on products and lots. Used, for exampel, in food industries: expiry date, alert date, date of removal, eso.",
	"update_xml" : ["product_expiry_view.xml"],
	"active": False,
	"installable": True
}
